@@ -477,7 +477,7 @@ example_two
 
 			exitCode, ok := err.(ExitCode)
 			Expect(ok).To(BeTrue())
-			Expect(exitCode.Value).To(Equal(0))
+			Expect(exitCode.Value()).To(Equal(0))
 		})
 
 		It("should create exit code one if there are changes", func() {
@@ -492,7 +492,7 @@ example_two
 
 			exitCode, ok := err.(ExitCode)
 			Expect(ok).To(BeTrue())
-			Expect(exitCode.Value).To(Equal(1))
+			Expect(exitCode.Value()).To(Equal(1))
 		})
 
 		It("should fail with an exit code other than zero or one in case of an error", func() {
@@ -501,7 +501,7 @@ example_two
 
 			exitCode, ok := err.(ExitCode)
 			Expect(ok).To(BeTrue())
-			Expect(exitCode.Value).To(Equal(255))
+			Expect(exitCode.Value()).To(Equal(255))
 		})
 
 		It("should accept a list of paths and filter the report based on these", func() {
@@ -591,6 +591,24 @@ spec.replicas  (apps/v1/Deployment/test)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(out).To(BeEquivalentTo("\n"))
 		})
+
+		It("should ignore the changes in values", func() {
+			expected := `
+(root level)  (v1/Namespace/test)
+- one document removed:
+  ---
+  apiVersion: v1
+  kind: Namespace
+  metadata:
+    name: test
+
+`
+			By("using the --ignore-value-changes", func() {
+				out, err := dyff("between", "--omit-header", "--ignore-value-changes", assets("issues", "issue-232", "from.yml"), assets("issues", "issue-232", "to.yml"))
+				Expect(err).ToNot(HaveOccurred())
+				Expect(out).To(BeEquivalentTo(expected))
+			})
+		})
 	})
 
 	Context("last-applied command", func() {
